@@ -1,10 +1,12 @@
 from .jdoodle import Compiler
+from .jdoodle import Output
+from .errors import LimitExceeded, LinkNotSupported, LanguageNotSupported, UnauthorizedRequest, BadRequest
 
 ############
 # METADATA #
 ############
 
-__version__ = "v1.1.1"
+__version__ = "v1.1.2"
 __title__ = "pydoodle"
 __license__ = "MIT"
 __author__ = "Prince2347X"
