@@ -3,6 +3,11 @@ class LanguageNotSupported(Exception):
     pass
 
 
+class LimitExceeded(Exception):
+    """Raised when the daily limit has exceeded. Learn more: https://jdoodle.com/compiler-api"""
+    pass
+
+
 class UnauthorizedRequest(Exception):
     """Raised if either your clientID or clientSecret is invalid."""
     pass
@@ -12,6 +17,7 @@ class BadRequest(Exception):
     """Raised when invalid language or versionIndex is provided. """
     pass
 
+
 class LinkNotSupported(Exception):
     """Raised if the provided link isn't supported yet by pydoodle."""
     pass
